@@ -24,7 +24,7 @@
 #define MP4V2_PROJECT_repo_rev        493
 #define MP4V2_PROJECT_repo_date       "2012-05-20 15:16:54 -0700 (Sun, 20 May 2012)"
 #define MP4V2_PROJECT_repo_type       "stable"
-#define MP4V2_PROJECT_build           "Mon Mar 22 07:31:26 MDT 2021"
+#define MP4V2_PROJECT_build           "Sun May  2 11:30:06 MDT 2021"
 
 /*****************************************************************************/
 
